@@ -42,7 +42,6 @@ import gtk
 
 class Studio:
 
-    EXPORT_FORMATS = ['HTML', 'ODT']
     TARGET_TYPE_URI_LIST = 80
 
     def __init__(self):
@@ -58,6 +57,11 @@ class Studio:
         language = gettext.translation(OCRFEEDER_COMPACT_NAME, LOCALE_DIR,
                                        languages = languages, fallback = True)
         _ = language.gettext
+
+        self.EXPORT_FORMATS = {0: (self.exportToHtml, _('HTML')),
+                               1: (self.exportToOdt, _('ODT')),
+                               2: (self.exportToPlaintext, _('Plain Text'))}
+
         self.title = OCRFEEDER_STUDIO_NAME
         self.main_window = widgetPresenter.MainWindow()
         self.main_window.setTitle(self.title)
@@ -83,8 +87,9 @@ class Studio:
                                                                self.configuration_manager)
         self.project_name = None
 
-        toolbar_callback_dict = {'detection': self.__recognizeCurrentPageAction,
-                         'export_to_odt': self.exportToOdt}
+        toolbar_callback_dict = {'recognizePage': self.__recognizePageAction,
+                                 'recognizeDocument': self.__recognizeDocumentAction,
+                                 'export_to_odt': self.exportToOdt}
 
         menubar_callback_dict = {'exit': self.quit, 'add_image': self.addImage, 'export_to_odt': self.exportToOdt, 'edit_page': self.choosePageSize,
                                  'delete_page': self.deleteCurrentPage, 'export_dialog': self.exportDialog, 'add_folder': self.addFolder,
@@ -189,7 +194,7 @@ class Studio:
                                                         self.main_window.window)
         item_obtain = AsyncItem(lib.obtainScanners,(),
                                 self.__obtainScannersFinishedCb,(dialog,))
-        info_obtain = (_('Obtaining scanners'), _('Please wait…'))
+        info_obtain = (_('Obtaining scanners'), _(u'Please wait…'))
         dialog.setItemsList([(info_obtain, item_obtain)])
         dialog.run()
 
@@ -215,7 +220,7 @@ class Studio:
                 self.main_window.window)
             item_scan = AsyncItem(lib.scan,(device,),
                                   self.__scanFinishedCb,(dialog_scan,))
-            info_scan = (_('Scanning'), _('Please wait…'))
+            info_scan = (_('Scanning'), _(u'Please wait…'))
             dialog_scan.setItemsList([(info_scan, item_scan)])
             dialog_scan.run()
         else:
@@ -257,7 +262,7 @@ class Studio:
                               self.configuration_manager.temporary_dir),
                              self.__loadPdfFinishedCb,
                              (dialog,))
-            info = (_('Loading PDF'), _('Please wait…'))
+            info = (_('Loading PDF'), _(u'Please wait…'))
             dialog.setItemsList([(info, item)])
             dialog.run()
 
@@ -279,13 +284,20 @@ class Studio:
     def exportToOdt(self, widget = None):
         self.source_images_controler.exportPagesToOdt(self.source_images_selector.getPixbufsSorted())
 
+    def exportToPlaintext(self, widget = None):
+        self.source_images_controler.exportPagesToPlaintext(self.source_images_selector.getPixbufsSorted())
+
     def exportDialog(self, widget):
-        export_dialog = widgetPresenter.ExportDialog(_('Export pages'), self.EXPORT_FORMATS)
+        format_names = [format[1] for format in self.EXPORT_FORMATS.values()]
+        export_dialog = widgetPresenter.ExportDialog(_('Export pages'), format_names)
         response = export_dialog.run()
         if response == gtk.RESPONSE_ACCEPT:
-            format = export_dialog.getSelectedFormat().capitalize()
+            format = export_dialog.getSelectedFormat()
             export_dialog.destroy()
-            exec('self.exportTo%s()' % format)
+            if format != -1:
+                # Retrieve and run the exportation function
+                exportation_function = self.EXPORT_FORMATS[format][0]
+                exportation_function()
             return None
         export_dialog.destroy()
         return None
@@ -306,9 +318,12 @@ class Studio:
             return
         self.source_images_controler.addImages(images)
 
-    def __recognizeCurrentPageAction(self, widget):
+    def __recognizePageAction(self, widget):
         self.source_images_controler.recognizeCurrentPage()
 
+    def __recognizeDocumentAction(self, widget):
+        self.source_images_controler.recognizeDocument()
+
     def setProjectName(self, project_name):
         self.project_name = project_name
         project_title = os.path.splitext(os.path.basename(self.project_name))[0]
@@ -338,7 +353,12 @@ class Studio:
             self.setProjectName(project_title)
 
     def clear(self, widget = None):
-        self.source_images_controler.clear()
+        dialog = widgetPresenter.QuestionDialog(_('Are you sure you want '
+                                                  'to clear the project?'))
+        response = dialog.run()
+        if response == gtk.RESPONSE_YES:
+            self.source_images_controler.clear()
+        dialog.destroy()
 
     def unpaper(self, widget = None):
         self.source_images_controler.unpaperTool()
